# Sphinx Callouts

A Sphinx extension that adds support for callouts.

[![PyPI version](https://img.shields.io/pypi/v/sphinx-callouts.svg)](https://pypi.python.org/pypi/sphinx-callouts)
[![Downloads](https://static.pepy.tech/badge/sphinx-callouts/month)](https://pepy.tech/project/sphinx-callouts)
[![Parallel Safe](https://img.shields.io/badge/parallel%20safe-true-brightgreen)](#)

## Documentation

See [sphinx-callouts documentation](https://sphinx-callouts.readthedocs.io/en/latest/index.html) for installation and configuration instructions.

## Contributing

Pull Requests welcome! See [Contributing](https://sphinx-callouts.readthedocs.io/en/latest/contributing.html) for instructions on how best to contribute.

## License

Apache-2.0 - see LICENSE file for details.

Code adapted from [https://github.com/ray-project/ray/](https://github.com/ray-project/ray/blob/master/doc/source/_ext/callouts.py) (Apache-2.0 License)
